contexttools.iterate_contexts_backward_in_expr
==============================================

.. autofunction:: abjad.tools.contexttools.iterate_contexts_backward_in_expr.iterate_contexts_backward_in_expr
